@@ -2,7 +2,7 @@
 
 # pykar - KAR/MID Karaoke Player
 #
-# Copyright (C) 2007  Kelvin Lawson (kelvinl@users.sf.net)
+# Copyright (C) 2010 Kelvin Lawson (kelvinl@users.sf.net)
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -50,6 +50,12 @@
 # To play the MIDI songs on Linux, Timidity++ is also required:
 # . Timidity++ (timidity.sourceforge.net)
 
+# OSX REQUIREMENTS
+#
+# On OSX, pygame will run MIDI natively by default, but if the GUS
+# patches are installed in /usr/local/lib/timidity, it will run MIDI
+# via Timidity instead, which appears to work better than the native
+# support, so we recommend this.
 
 # USAGE INSTRUCTIONS
 #
@@ -1010,19 +1016,14 @@ class midPlayer(pykPlayer):
         # to the first note), so no need for the earliest note hack
         # there.  On timidity-based platforms, we anticipate our
         # lyrics display by the time of the first note.
-        if env != ENV_WINDOWS and env != ENV_OSX:
+
+        # Note: pygame on OSX can run MIDI natively, or if the GUS
+        # patches are installed in /usr/local/lib/timidity, it will
+        # run MIDI via Timidity instead, which appears to work better
+        # than the native support, so we recommend this.
+        if env != ENV_WINDOWS:
             self.InternalOffsetTime += self.midifile.earliestNoteMS
 
-        if env == ENV_LINUX:
-            # For some reason, a further offset of -250 ms seems about
-            # right empirically, on Linux, but not on Windows or on
-            # the GP2X.
-
-            # Actually, on further experimentation, this seems to be
-            # specific to my particular machine.  Leave it out.
-            #self.InternalOffsetTime -= 250
-            pass
-
         # Now word-wrap the text to fit our window.
         self.lyrics = self.midifile.lyrics.wordWrapLyrics(self.font)
 
@@ -1032,10 +1033,10 @@ class midPlayer(pykPlayer):
         self.useMidiTimer = True
 
         if env == ENV_WINDOWS:
-            # Unless we're running on Windows.  For some reason, MIDI
-            # playback on Windows reports an unreliable time.  To
-            # avoid that problem, we'll always use the CPU timer
-            # instead of the MIDI timer.
+            # Unless we're running on Windows (i.e., not timidity).
+            # For some reason, hardware MIDI playback can report an
+            # unreliable time.  To avoid that problem, we'll always
+            # use the CPU timer instead of the MIDI timer.
             self.useMidiTimer = False
 
         # Load the MIDI player
@@ -1046,7 +1047,10 @@ class midPlayer(pykPlayer):
 
         else:
             # Load the sound normally for playback.
-            pygame.mixer.music.load(self.SongDatas[0].GetFilepath())
+            audio_path = self.SongDatas[0].GetFilepath()
+            if type(audio_path) == unicode:
+                audio_path = audio_path.encode(sys.getfilesystemencoding())
+            pygame.mixer.music.load(audio_path)
 
             # Set an event for when the music finishes playing
             pygame.mixer.music.set_endevent(pygame.USEREVENT)
@@ -1247,6 +1251,14 @@ class midPlayer(pykPlayer):
             if self.currentMs > self.midifile.lastNoteMS:
                 self.Close()
 
+    def handleEvent(self, event):
+        if event.type == pygame.KEYDOWN and event.key == pygame.K_RETURN and (event.mod & (pygame.KMOD_LSHIFT | pygame.KMOD_RSHIFT | pygame.KMOD_LMETA | pygame.KMOD_RMETA)):
+            # Shift/meta return: start/stop song.  Useful for keybinding apps.
+            self.Close()
+            return
+        
+        pykPlayer.handleEvent(self, event)
+
     def doResize(self, newSize):
         # This will be called internally whenever the window is
         # resized for any reason, either due to an application resize
